/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 77 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"

#line 111 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 81 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 84 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 87 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 90 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 147 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 150 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 209 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 240 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 245 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 248 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 251 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 254 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 257 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 260 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 263 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 266 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 269 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 272 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 275 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 278 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 281 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 284 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelScatterDataProxy.cpp"


class sipQtDataVisualization_QItemModelScatterDataProxy : public ::QtDataVisualization::QItemModelScatterDataProxy
{
public:
    sipQtDataVisualization_QItemModelScatterDataProxy(::QAbstractItemModel*, ::QObject*);
    sipQtDataVisualization_QItemModelScatterDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, ::QObject*);
    sipQtDataVisualization_QItemModelScatterDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, const ::QString&, ::QObject*);
    sipQtDataVisualization_QItemModelScatterDataProxy(::QObject*);
    virtual ~sipQtDataVisualization_QItemModelScatterDataProxy();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QItemModelScatterDataProxy(const sipQtDataVisualization_QItemModelScatterDataProxy &);
    sipQtDataVisualization_QItemModelScatterDataProxy &operator = (const sipQtDataVisualization_QItemModelScatterDataProxy &);

    char sipPyMethods[7];
};

sipQtDataVisualization_QItemModelScatterDataProxy::sipQtDataVisualization_QItemModelScatterDataProxy(::QAbstractItemModel*a0, ::QObject*a1): ::QtDataVisualization::QItemModelScatterDataProxy(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelScatterDataProxy::sipQtDataVisualization_QItemModelScatterDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, ::QObject*a4): ::QtDataVisualization::QItemModelScatterDataProxy(a0, a1, a2, a3, a4), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelScatterDataProxy::sipQtDataVisualization_QItemModelScatterDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, const ::QString& a4, ::QObject*a5): ::QtDataVisualization::QItemModelScatterDataProxy(a0, a1, a2, a3, a4, a5), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelScatterDataProxy::sipQtDataVisualization_QItemModelScatterDataProxy(::QObject*a0): ::QtDataVisualization::QItemModelScatterDataProxy(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelScatterDataProxy::~sipQtDataVisualization_QItemModelScatterDataProxy()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QItemModelScatterDataProxy::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QItemModelScatterDataProxy);

    return ::QtDataVisualization::QItemModelScatterDataProxy::metaObject();
}

int sipQtDataVisualization_QItemModelScatterDataProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QItemModelScatterDataProxy::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QItemModelScatterDataProxy::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QItemModelScatterDataProxy::qt_metacast(_clname));
}

bool sipQtDataVisualization_QItemModelScatterDataProxy::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QItemModelScatterDataProxy::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QItemModelScatterDataProxy::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QItemModelScatterDataProxy::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QItemModelScatterDataProxy::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelScatterDataProxy::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelScatterDataProxy::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelScatterDataProxy::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelScatterDataProxy::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelScatterDataProxy::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelScatterDataProxy::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelScatterDataProxy::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelScatterDataProxy::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelScatterDataProxy::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setItemModel, "setItemModel(self, itemModel: QAbstractItemModel|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setItemModel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setItemModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, &a0Keep, sipType_QAbstractItemModel, &a0))
        {
            sipCpp->setItemModel(a0);

            sipKeepReference(sipSelf, 120, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setItemModel, doc_QtDataVisualization_QItemModelScatterDataProxy_setItemModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_itemModel, "itemModel(self) -> QAbstractItemModel|None");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_itemModel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_itemModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QAbstractItemModel*sipRes;

            sipRes = sipCpp->itemModel();

            return sipConvertFromType(sipRes, sipType_QAbstractItemModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_itemModel, doc_QtDataVisualization_QItemModelScatterDataProxy_itemModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRole, "setXPosRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setXPosRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setXPosRole, doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRole, "xPosRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->xPosRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_xPosRole, doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRole, "setYPosRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setYPosRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setYPosRole, doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRole, "yPosRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->yPosRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_yPosRole, doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRole, "setZPosRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setZPosRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setZPosRole, doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRole, "zPosRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->zPosRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_zPosRole, doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRole, "setRotationRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRotationRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setRotationRole, doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRole, "rotationRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rotationRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_rotationRole, doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_remap, "remap(self, xPosRole: str|None, yPosRole: str|None, zPosRole: str|None, rotationRole: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_remap(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_remap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1J1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State))
        {
            sipCpp->remap(*a0, *a1, *a2, *a3);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_remap, doc_QtDataVisualization_QItemModelScatterDataProxy_remap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRolePattern, "setXPosRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setXPosRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setXPosRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRolePattern, "xPosRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->xPosRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_xPosRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRolePattern, "setYPosRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setYPosRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setYPosRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRolePattern, "yPosRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->yPosRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_yPosRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRolePattern, "setZPosRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setZPosRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setZPosRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRolePattern, "zPosRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->zPosRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_zPosRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRolePattern, "setRotationRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setRotationRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setRotationRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRolePattern, "rotationRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->rotationRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_rotationRolePattern, doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRoleReplace, "setXPosRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setXPosRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setXPosRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRoleReplace, "xPosRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->xPosRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_xPosRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRoleReplace, "setYPosRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setYPosRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setYPosRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRoleReplace, "yPosRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->yPosRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_yPosRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRoleReplace, "setZPosRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setZPosRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setZPosRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRoleReplace, "zPosRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->zPosRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_zPosRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRoleReplace, "setRotationRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRotationRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_setRotationRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRoleReplace, "rotationRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelScatterDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rotationRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelScatterDataProxy, sipName_rotationRoleReplace, doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRoleReplace);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QItemModelScatterDataProxy(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QItemModelScatterDataProxy(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp = reinterpret_cast< ::QtDataVisualization::QItemModelScatterDataProxy *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QItemModelScatterDataProxy)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_QScatterDataProxy)->ctd_cast(static_cast< ::QtDataVisualization::QScatterDataProxy *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QItemModelScatterDataProxy(void *, int);}
static void release_QtDataVisualization_QItemModelScatterDataProxy(void *sipCppV, int)
{
    ::QtDataVisualization::QItemModelScatterDataProxy *sipCpp = reinterpret_cast< ::QtDataVisualization::QItemModelScatterDataProxy *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QItemModelScatterDataProxy(Py_ssize_t);}
static void *array_QtDataVisualization_QItemModelScatterDataProxy(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QItemModelScatterDataProxy[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QItemModelScatterDataProxy(void *);}
static void array_delete_QtDataVisualization_QItemModelScatterDataProxy(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QItemModelScatterDataProxy *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QItemModelScatterDataProxy(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QItemModelScatterDataProxy(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QItemModelScatterDataProxy *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QItemModelScatterDataProxy(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QItemModelScatterDataProxy(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QItemModelScatterDataProxy(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QItemModelScatterDataProxy *sipCpp = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelScatterDataProxy(a0, a1);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        ::QObject* a4 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QObject, &a4, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelScatterDataProxy(a0, *a1, *a2, *a3, a4);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QString* a4;
        int a4State = 0;
        ::QObject* a5 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QString, &a4, &a4State, sipType_QObject, &a5, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelScatterDataProxy(a0, *a1, *a2, *a3, *a4, a5);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelScatterDataProxy(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QItemModelScatterDataProxy[] = {{62, 255, 1}};


static PyMethodDef methods_QtDataVisualization_QItemModelScatterDataProxy[] = {
    {sipName_itemModel, meth_QtDataVisualization_QItemModelScatterDataProxy_itemModel, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_itemModel},
    {sipName_remap, meth_QtDataVisualization_QItemModelScatterDataProxy_remap, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_remap},
    {sipName_rotationRole, meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRole},
    {sipName_rotationRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRolePattern},
    {sipName_rotationRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_rotationRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_rotationRoleReplace},
    {sipName_setItemModel, meth_QtDataVisualization_QItemModelScatterDataProxy_setItemModel, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setItemModel},
    {sipName_setRotationRole, meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRole},
    {sipName_setRotationRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRolePattern},
    {sipName_setRotationRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_setRotationRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setRotationRoleReplace},
    {sipName_setXPosRole, meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRole},
    {sipName_setXPosRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRolePattern},
    {sipName_setXPosRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_setXPosRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setXPosRoleReplace},
    {sipName_setYPosRole, meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRole},
    {sipName_setYPosRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRolePattern},
    {sipName_setYPosRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_setYPosRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setYPosRoleReplace},
    {sipName_setZPosRole, meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRole},
    {sipName_setZPosRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRolePattern},
    {sipName_setZPosRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_setZPosRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_setZPosRoleReplace},
    {sipName_xPosRole, meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRole},
    {sipName_xPosRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRolePattern},
    {sipName_xPosRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_xPosRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_xPosRoleReplace},
    {sipName_yPosRole, meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRole},
    {sipName_yPosRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRolePattern},
    {sipName_yPosRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_yPosRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_yPosRoleReplace},
    {sipName_zPosRole, meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRole, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRole},
    {sipName_zPosRolePattern, meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRolePattern},
    {sipName_zPosRoleReplace, meth_QtDataVisualization_QItemModelScatterDataProxy_zPosRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelScatterDataProxy_zPosRoleReplace}
};

PyDoc_STRVAR(doc_QtDataVisualization_QItemModelScatterDataProxy, "\1QItemModelScatterDataProxy(itemModel: QAbstractItemModel|None, parent: QObject|None = None)\n"
"QItemModelScatterDataProxy(itemModel: QAbstractItemModel|None, xPosRole: str|None, yPosRole: str|None, zPosRole: str|None, parent: QObject|None = None)\n"
"QItemModelScatterDataProxy(itemModel: QAbstractItemModel|None, xPosRole: str|None, yPosRole: str|None, zPosRole: str|None, rotationRole: str|None, parent: QObject|None = None)\n"
"QItemModelScatterDataProxy(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QItemModelScatterDataProxy[] = {
    {"zPosRoleReplaceChanged(QString)", "\1zPosRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"yPosRoleReplaceChanged(QString)", "\1yPosRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"xPosRoleReplaceChanged(QString)", "\1xPosRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationRoleReplaceChanged(QString)", "\1rotationRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationRolePatternChanged(QRegExp)", "\1rotationRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"zPosRolePatternChanged(QRegExp)", "\1zPosRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"yPosRolePatternChanged(QRegExp)", "\1yPosRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"xPosRolePatternChanged(QRegExp)", "\1xPosRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationRoleChanged(QString)", "\1rotationRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"zPosRoleChanged(QString)", "\1zPosRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"yPosRoleChanged(QString)", "\1yPosRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"xPosRoleChanged(QString)", "\1xPosRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemModelChanged(const QAbstractItemModel*)", "\1itemModelChanged(self, itemModel: QAbstractItemModel|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QItemModelScatterDataProxy = {
    &::QtDataVisualization::QItemModelScatterDataProxy::staticMetaObject,
    0,
    signals_QtDataVisualization_QItemModelScatterDataProxy,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelScatterDataProxy = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QItemModelScatterDataProxy,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QItemModelScatterDataProxy,
    },
    {
        sipNameNr_QItemModelScatterDataProxy,
        {0, 0, 1},
        27, methods_QtDataVisualization_QItemModelScatterDataProxy,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QItemModelScatterDataProxy,
    -1,
    -1,
    supers_QtDataVisualization_QItemModelScatterDataProxy,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QItemModelScatterDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QItemModelScatterDataProxy,
    SIP_NULLPTR,
    array_QtDataVisualization_QItemModelScatterDataProxy,
    SIP_NULLPTR,
    release_QtDataVisualization_QItemModelScatterDataProxy,
    cast_QtDataVisualization_QItemModelScatterDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QItemModelScatterDataProxy,
    sizeof (::QtDataVisualization::QItemModelScatterDataProxy),
};
